<a id="mypy-boto3-ram"></a>

# mypy-boto3-ram

[![PyPI - types-aiobotocore-ram](https://img.shields.io/pypi/v/types-aiobotocore-ram.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ram)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-ram.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ram)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-ram?color=blue)](https://pypistats.org/packages/types-aiobotocore-ram)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.RAM 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-ram docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ram/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-ram](#mypy-boto3-ram)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `RAM`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `RAM` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[ram]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[ram]'

# standalone installation
python -m pip install types-aiobotocore-ram
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[ram]` in your environment:
  `python -m pip install 'types-aiobotocore[ram]'`

Both type checking and auto-complete should work for `RAM` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[ram]` in your environment:
  `python -m pip install 'types-aiobotocore[ram]'`

Both type checking and auto-complete should work for `RAM` service. No explicit
type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[ram]` in your environment:
  `python -m pip install 'types-aiobotocore[ram]'`
- Run `mypy` as usual

Type checking should work for `RAM` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[ram]` in your environment:
  `python -m pip install 'types-aiobotocore[ram]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `RAM` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`RAMClient` provides annotations for `session.create_client("ram")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ram import RAMClient

session = get_session()
async with session.create_client("ram") as client:
    client: RAMClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_ram.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_ram import RAMClient
from types_aiobotocore_ram.paginator import (
    GetResourcePoliciesPaginator,
    GetResourceShareAssociationsPaginator,
    GetResourceShareInvitationsPaginator,
    GetResourceSharesPaginator,
    ListPrincipalsPaginator,
    ListResourcesPaginator,
)

session = get_session()
async with session.create_client("ram") as client:
    client: RAMClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator("get_resource_policies")
        get_resource_share_associations_paginator: GetResourceShareAssociationsPaginator = client.get_paginator("get_resource_share_associations")
        get_resource_share_invitations_paginator: GetResourceShareInvitationsPaginator = client.get_paginator("get_resource_share_invitations")
        get_resource_shares_paginator: GetResourceSharesPaginator = client.get_paginator("get_resource_shares")
        list_principals_paginator: ListPrincipalsPaginator = client.get_paginator("list_principals")
        list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
    ```







### Literals

`types_aiobotocore_ram.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_ram.literals import (
    GetResourcePoliciesPaginatorName,
    GetResourceShareAssociationsPaginatorName,
    GetResourceShareInvitationsPaginatorName,
    GetResourceSharesPaginatorName,
    ListPrincipalsPaginatorName,
    ListResourcesPaginatorName,
    ResourceOwnerType,
    ResourceRegionScopeFilterType,
    ResourceRegionScopeType,
    ResourceShareAssociationStatusType,
    ResourceShareAssociationTypeType,
    ResourceShareFeatureSetType,
    ResourceShareInvitationStatusType,
    ResourceShareStatusType,
    ResourceStatusType,
    ServiceName,
    PaginatorName,
)

def check_value(value: GetResourcePoliciesPaginatorName) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_ram.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_ram.type_defs import (
    AcceptResourceShareInvitationRequestRequestTypeDef,
    AcceptResourceShareInvitationResponseTypeDef,
    AssociateResourceSharePermissionRequestRequestTypeDef,
    AssociateResourceSharePermissionResponseTypeDef,
    AssociateResourceShareRequestRequestTypeDef,
    AssociateResourceShareResponseTypeDef,
    CreateResourceShareRequestRequestTypeDef,
    CreateResourceShareResponseTypeDef,
    DeleteResourceShareRequestRequestTypeDef,
    DeleteResourceShareResponseTypeDef,
    DisassociateResourceSharePermissionRequestRequestTypeDef,
    DisassociateResourceSharePermissionResponseTypeDef,
    DisassociateResourceShareRequestRequestTypeDef,
    DisassociateResourceShareResponseTypeDef,
    EnableSharingWithAwsOrganizationResponseTypeDef,
    GetPermissionRequestRequestTypeDef,
    GetPermissionResponseTypeDef,
    GetResourcePoliciesRequestRequestTypeDef,
    GetResourcePoliciesResponseTypeDef,
    GetResourceShareAssociationsRequestRequestTypeDef,
    GetResourceShareAssociationsResponseTypeDef,
    GetResourceShareInvitationsRequestRequestTypeDef,
    GetResourceShareInvitationsResponseTypeDef,
    GetResourceSharesRequestRequestTypeDef,
    GetResourceSharesResponseTypeDef,
    ListPendingInvitationResourcesRequestRequestTypeDef,
    ListPendingInvitationResourcesResponseTypeDef,
    ListPermissionsRequestRequestTypeDef,
    ListPermissionsResponseTypeDef,
    ListPrincipalsRequestRequestTypeDef,
    ListPrincipalsResponseTypeDef,
    ListResourceSharePermissionsRequestRequestTypeDef,
    ListResourceSharePermissionsResponseTypeDef,
    ListResourceTypesRequestRequestTypeDef,
    ListResourceTypesResponseTypeDef,
    ListResourcesRequestRequestTypeDef,
    ListResourcesResponseTypeDef,
    PaginatorConfigTypeDef,
    PrincipalTypeDef,
    PromoteResourceShareCreatedFromPolicyRequestRequestTypeDef,
    PromoteResourceShareCreatedFromPolicyResponseTypeDef,
    RejectResourceShareInvitationRequestRequestTypeDef,
    RejectResourceShareInvitationResponseTypeDef,
    ResourceShareAssociationTypeDef,
    ResourceShareInvitationTypeDef,
    ResourceSharePermissionDetailTypeDef,
    ResourceSharePermissionSummaryTypeDef,
    ResourceShareTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    ServiceNameAndResourceTypeTypeDef,
    TagFilterTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateResourceShareRequestRequestTypeDef,
    UpdateResourceShareResponseTypeDef,
)

def get_structure() -> AcceptResourceShareInvitationRequestRequestTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-ram` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-ram docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ram/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
